import { ZERO } from '@/constants/common';
import { searchedFromMapBioEntityElement } from '@/redux/bioEntity/bioEntity.selectors';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { DrawerHeading } from '@/shared/DrawerHeading';
import { AnnotationItem } from './AnnotationItem';
import { AssociatedSubmap } from './AssociatedSubmap';

export const BioEntityDrawer = (): React.ReactNode => {
  const bioEntityData = useAppSelector(searchedFromMapBioEntityElement);

  if (!bioEntityData) {
    return null;
  }

  const isReferenceAvailable = bioEntityData.references.length > ZERO;

  return (
    <div className="h-full max-h-full" data-testid="bioentity-drawer">
      <DrawerHeading
        title={
          <>
            <span className="font-normal">{bioEntityData.stringType}:</span>&nbsp;
            {bioEntityData.name}
          </>
        }
      />
      <div className="flex flex-col gap-6 p-6">
        <div className="text-sm font-normal">
          Compartment: <b className="font-semibold">{bioEntityData.compartmentName}</b>
        </div>
        {bioEntityData.fullName && (
          <div className="text-sm font-normal">
            Full name: <b className="font-semibold">{bioEntityData.fullName}</b>
          </div>
        )}
        <h3 className="font-semibold">
          Annotations:{' '}
          {!isReferenceAvailable && <span className="font-normal">No annotations</span>}
        </h3>
        {isReferenceAvailable &&
          bioEntityData.references.map(reference => (
            <AnnotationItem
              key={reference.id}
              type={reference.type}
              link={reference.link}
              resource={reference.resource}
            />
          ))}
        <AssociatedSubmap />
      </div>
    </div>
  );
};
