import { useContext } from 'react';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import {
  elementAnnotationsSelector,
  loadingStatisticsSelector,
} from '@/redux/statistics/statistics.selectors';
import { ZERO } from '@/constants/common';
import { CheckboxFilter } from '../../CheckboxFilter';
import { CollapsibleSection } from '../../CollapsibleSection';
import { ExportContext } from '../ExportCompound.context';

export const Annotations = (): React.ReactNode => {
  const { setAnnotations } = useContext(ExportContext);
  const loadingStatistics = useAppSelector(loadingStatisticsSelector);
  const elementAnnotations = useAppSelector(elementAnnotationsSelector);
  const isPending = loadingStatistics === 'pending';

  const mappedElementAnnotations = elementAnnotations
    ? Object.keys(elementAnnotations)?.map(el => ({ id: el, label: el }))
    : [];

  return (
    <CollapsibleSection title="Select annotations">
      {isPending && <p>Loading...</p>}
      {!isPending && mappedElementAnnotations && mappedElementAnnotations.length > ZERO && (
        <CheckboxFilter options={mappedElementAnnotations} onCheckedChange={setAnnotations} />
      )}
    </CollapsibleSection>
  );
};
