import { ReactNode, useCallback, useMemo, useState } from 'react';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { modelsIdsSelector } from '@/redux/models/models.selectors';
import { CheckboxItem } from '../CheckboxFilter/CheckboxFilter.component';
import { Types } from './Types';
import { Columns } from './Columns';
import { Annotations } from './Annotations';
import { ExcludedCompartmentPathways } from './ExcludedCompartmentPathways';
import { IncludedCompartmentPathways } from './IncludedCompartmentPathways ';
import { DownloadElements } from './DownloadElements/DownloadElements';
import { ExportContext } from './ExportCompound.context';
import { getNetworkDownloadBodyRequest } from './utils/getNetworkBodyRequest';
import { getDownloadElementsBodyRequest } from './utils/getDownloadElementsBodyRequest';

type ExportProps = {
  children: ReactNode;
};

export const Export = ({ children }: ExportProps): JSX.Element => {
  const [types, setTypes] = useState<CheckboxItem[]>([]);
  const [columns, setColumns] = useState<CheckboxItem[]>([]);
  const [annotations, setAnnotations] = useState<CheckboxItem[]>([]);
  const modelIds = useAppSelector(modelsIdsSelector);
  const [includedCompartmentPathways, setIncludedCompartmentPathways] = useState<CheckboxItem[]>(
    [],
  );
  const [excludedCompartmentPathways, setExcludedCompartmentPathways] = useState<CheckboxItem[]>(
    [],
  );

  const handleDownloadElements = useCallback(() => {
    getDownloadElementsBodyRequest({
      types,
      columns,
      modelIds,
      annotations,
      includedCompartmentPathways,
      excludedCompartmentPathways,
    });
  }, [
    types,
    columns,
    modelIds,
    annotations,
    includedCompartmentPathways,
    excludedCompartmentPathways,
  ]);

  const handleDownloadNetwork = useCallback(() => {
    getNetworkDownloadBodyRequest();
  }, []);

  const globalContextValue = useMemo(
    () => ({
      setTypes,
      setColumns,
      setAnnotations,
      setIncludedCompartmentPathways,
      setExcludedCompartmentPathways,
      handleDownloadElements,
      handleDownloadNetwork,
    }),
    [handleDownloadElements, handleDownloadNetwork],
  );

  return <ExportContext.Provider value={globalContextValue}>{children}</ExportContext.Provider>;
};

Export.Types = Types;
Export.Columns = Columns;
Export.Annotations = Annotations;
Export.IncludedCompartmentPathways = IncludedCompartmentPathways;
Export.ExcludedCompartmentPathways = ExcludedCompartmentPathways;
Export.DownloadElements = DownloadElements;
