import { useContext } from 'react';
import {
  compartmentPathwaysDataSelector,
  loadingCompartmentPathwaysSelector,
} from '@/redux/compartmentPathways/compartmentPathways.selectors';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { ZERO } from '@/constants/common';
import { CheckboxFilter } from '../../CheckboxFilter';
import { CollapsibleSection } from '../../CollapsibleSection';
import { ExportContext } from '../ExportCompound.context';
import { getCompartmentPathwaysCheckboxElements } from '../utils/getCompartmentPathwaysCheckboxElements';

export const IncludedCompartmentPathways = (): React.ReactNode => {
  const { setIncludedCompartmentPathways } = useContext(ExportContext);
  const loadingCompartmentPathways = useAppSelector(loadingCompartmentPathwaysSelector);
  const isPending = loadingCompartmentPathways === 'pending';
  const compartmentPathways = useAppSelector(compartmentPathwaysDataSelector);
  const checkboxElements = getCompartmentPathwaysCheckboxElements(compartmentPathways);

  return (
    <CollapsibleSection title="Select included compartment / pathways">
      {isPending && <p>Loading...</p>}
      {!isPending && checkboxElements && checkboxElements.length > ZERO && (
        <CheckboxFilter
          options={checkboxElements}
          onCheckedChange={setIncludedCompartmentPathways}
        />
      )}
    </CollapsibleSection>
  );
};
