type ElementTypes =
  | {
      className: string;
      name: string;
      parentClass: string;
    }[]
  | undefined;

type MappedElementTypes = { id: string; label: string }[];

type PresenceMap = { [key: string]: boolean };

export const getCheckboxElements = (elementTypes: ElementTypes): MappedElementTypes => {
  if (!elementTypes) return [];

  const excludedTypes: PresenceMap = {};
  elementTypes?.forEach(type => {
    excludedTypes[type.parentClass] = true;
  });

  const mappedElementTypes: MappedElementTypes = [];
  const processedNames: PresenceMap = {};

  elementTypes.forEach(elementType => {
    if (excludedTypes[elementType.className] || processedNames[elementType.name]) return;

    processedNames[elementType.name] = true;
    mappedElementTypes.push({
      id: elementType.name,
      label: elementType.name,
    });
  });

  return mappedElementTypes;
};
