import { StoreType } from '@/redux/store';
import {
  InitialStoreState,
  getReduxWrapperWithStore,
} from '@/utils/testing/getReduxWrapperWithStore';
import { render, screen } from '@testing-library/react';
import { UserOverlays } from './UserOverlays.component';

const renderComponent = (initialStore?: InitialStoreState): { store: StoreType } => {
  const { Wrapper, store } = getReduxWrapperWithStore(initialStore);
  return (
    render(
      <Wrapper>
        <UserOverlays />
      </Wrapper>,
    ),
    {
      store,
    }
  );
};

describe('UserOverlays component', () => {
  it('renders loading message when user is loading', () => {
    renderComponent({
      user: {
        loading: 'pending',
        authenticated: false,
        error: { name: '', message: '' },
        login: null,
      },
    });

    expect(screen.getByText('Loading')).toBeInTheDocument();
  });

  it('renders login button when user is not authenticated', () => {
    renderComponent({
      user: {
        loading: 'failed',
        authenticated: false,
        error: { name: '', message: '' },
        login: null,
      },
    });

    expect(screen.getByLabelText('login button')).toBeInTheDocument();
  });

  it('dispatches openLoginModal action when Login button is clicked', () => {
    const { store } = renderComponent({
      user: {
        loading: 'failed',
        authenticated: false,
        error: { name: '', message: '' },
        login: null,
      },
      modal: {
        isOpen: false,
        modalName: 'none',
        modalTitle: '',
        overviewImagesState: {},
        molArtState: {},
      },
    });
    screen.getByLabelText('login button').click();
    const state = store.getState().modal;
    expect(state.isOpen).toEqual(true);
    expect(state.modalName).toEqual('login');
  });

  it('renders add overlay button when user is authenticated', () => {
    renderComponent({
      user: {
        loading: 'succeeded',
        authenticated: true,
        error: { name: '', message: '' },
        login: 'test',
      },
    });

    expect(screen.getByLabelText('add overlay button')).toBeInTheDocument();
  });
});
