import { displayAddOverlaysDrawer } from '@/redux/drawer/drawer.slice';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { openLoginModal } from '@/redux/modal/modal.slice';
import { authenticatedUserSelector, loadingUserSelector } from '@/redux/user/user.selectors';
import { Button } from '@/shared/Button';

export const UserOverlays = (): JSX.Element => {
  const dispatch = useAppDispatch();
  const loadingUser = useAppSelector(loadingUserSelector);
  const authenticatedUser = useAppSelector(authenticatedUserSelector);
  const isPending = loadingUser === 'pending';

  const handleLoginClick = (): void => {
    dispatch(openLoginModal());
  };

  const handleAddOverlay = (): void => {
    dispatch(displayAddOverlaysDrawer());
  };

  return (
    <div className="p-6">
      {isPending && <h1>Loading</h1>}

      {!isPending && !authenticatedUser && (
        <>
          <p className="mb-5 font-semibold">User provided overlays:</p>
          <p className="mb-5 text-sm">
            You are not logged in, please login to upload and view custom overlays
          </p>
          <Button onClick={handleLoginClick} aria-label="login button">
            Login
          </Button>
        </>
      )}

      {authenticatedUser && (
        <div className="flex items-center justify-between">
          <p>User provided overlays:</p>
          <Button onClick={handleAddOverlay} aria-label="add overlay button">
            Add overlay
          </Button>
        </div>
      )}
    </div>
  );
};
