import { useAppSelector } from '@/redux/hooks/useAppSelector';
import { Icon } from '@/shared/Icon';
import { displayBioEntitiesList } from '@/redux/drawer/drawer.slice';
import { useAppDispatch } from '@/redux/hooks/useAppDispatch';
import { BioEntityContent } from '@/types/models';
import { mapOpenedMapsSelector } from '@/redux/map/map.selectors';
import { openMapAndSetActive, setActiveMap } from '@/redux/map/map.slice';

export interface BioEntitiesSubmapItemProps {
  mapName: string;
  mapId: number;
  numberOfEntities: string | number;
  bioEntities: BioEntityContent[];
}

export const BioEntitiesSubmapItem = ({
  mapName,
  mapId,
  numberOfEntities,
  bioEntities,
}: BioEntitiesSubmapItemProps): JSX.Element => {
  const dispatch = useAppDispatch();
  const openedMaps = useAppSelector(mapOpenedMapsSelector);

  const isMapAlreadyOpened = (modelId: number): boolean =>
    openedMaps.some(map => map.modelId === modelId);

  const openSubmap = (): void => {
    if (isMapAlreadyOpened(mapId)) {
      dispatch(setActiveMap({ modelId: mapId }));
    } else {
      dispatch(openMapAndSetActive({ modelId: mapId, modelName: mapName }));
    }
  };

  const onSubmapClick = (): void => {
    openSubmap();
    dispatch(displayBioEntitiesList(bioEntities));
  };

  return (
    <button
      onClick={onSubmapClick}
      type="button"
      className="flex flex-row flex-nowrap items-center justify-between pl-6 [&:not(:last-of-type)]:pb-4"
      data-testid="bio-entites-submap-button"
    >
      <p className="text-sm font-normal">
        {mapName} ({numberOfEntities})
      </p>
      <Icon name="arrow" className="h-6 w-6 fill-font-500" data-testid="arrow-icon" />
    </button>
  );
};
