import { varyPositionZoom } from '@/redux/map/map.slice';
import { SetBoundsResult, useSetBounds } from '@/utils/map/useSetBounds';
import { useCallback } from 'react';
import { useDispatch } from 'react-redux';
import { MAP_ZOOM_IN_DELTA, MAP_ZOOM_OUT_DELTA } from '../MappAdditionalActions.constants';
import { useVisibleBioEntitiesPolygonCoordinates } from './useVisibleBioEntitiesPolygonCoordinates';

interface UseAddtionalActionsResult {
  zoomIn(): void;
  zoomOut(): void;
  zoomInToBioEntities(): void;
}

export const useAddtionalActions = (): UseAddtionalActionsResult => {
  const dispatch = useDispatch();
  const setBounds = useSetBounds();
  const polygonCoordinates = useVisibleBioEntitiesPolygonCoordinates();

  const zoomInToBioEntities = (): SetBoundsResult | undefined => {
    if (!polygonCoordinates) {
      return undefined;
    }

    return setBounds(polygonCoordinates);
  };

  const varyZoomByDelta = useCallback(
    (delta: number) => {
      dispatch(varyPositionZoom({ delta }));
    },
    [dispatch],
  );

  return {
    zoomIn: () => varyZoomByDelta(MAP_ZOOM_IN_DELTA),
    zoomOut: () => varyZoomByDelta(MAP_ZOOM_OUT_DELTA),
    zoomInToBioEntities,
  };
};
