import { useMemo } from 'react';
import { usePointToProjection } from '@/utils/map/usePointToProjection';
import type Feature from 'ol/Feature';
import type Polygon from 'ol/geom/Polygon';
import { ZERO } from '@/constants/common';
import { useAppSelector } from '@/redux/hooks/useAppSelector';
import {
  getOverlayOrderSelector,
  overlayBioEntitiesForCurrentModelSelector,
} from '@/redux/overlayBioEntity/overlayBioEntity.selector';
import { createOverlayGeometryFeature } from './createOverlayGeometryFeature';
import { getPolygonLatitudeCoordinates } from './getPolygonLatitudeCoordinates';
import { useGetOverlayColor } from './useGetOverlayColor';

export const useOverlayFeatures = (): Feature<Polygon>[] => {
  const pointToProjection = usePointToProjection();
  const { getOverlayBioEntityColorByAvailableProperties } = useGetOverlayColor();
  const overlaysOrder = useAppSelector(getOverlayOrderSelector);
  const bioEntities = useAppSelector(overlayBioEntitiesForCurrentModelSelector);

  const features = useMemo(
    () =>
      bioEntities.map(entity => {
        /**
         * Depending on number of active overlays
         * it's required to calculate xMin and xMax coordinates of the polygon
         * so "entity" might be devided equality between active overlays
         */
        const { xMin, xMax } = getPolygonLatitudeCoordinates({
          width: entity.width,
          nOverlays: overlaysOrder.length,
          xMin: entity.x1,
          overlayIndexBasedOnOrder:
            overlaysOrder.find(({ id }) => id === entity.overlayId)?.index || ZERO,
        });

        return createOverlayGeometryFeature(
          [
            ...pointToProjection({ x: xMin, y: entity.y1 }),
            ...pointToProjection({ x: xMax, y: entity.y2 }),
          ],
          getOverlayBioEntityColorByAvailableProperties(entity),
        );
      }),
    [overlaysOrder, bioEntities, pointToProjection, getOverlayBioEntityColorByAvailableProperties],
  );

  return features;
};
