import { chemicalSchema } from '@/models/chemicalSchema';
import { apiPath } from '@/redux/apiPath';
import { axiosInstanceNewAPI } from '@/services/api/utils/axiosInstance';
import { Chemical } from '@/types/models';
import { validateDataUsingZodSchema } from '@/utils/validateDataUsingZodSchema';
import { createAsyncThunk } from '@reduxjs/toolkit';
import { z } from 'zod';

export const getChemicals = createAsyncThunk(
  'project/getChemicals',
  async (searchQuery: string): Promise<Chemical[] | undefined> => {
    const response = await axiosInstanceNewAPI.get<Chemical[]>(
      apiPath.getChemicalsStringWithQuery(searchQuery),
    );

    const isDataValid = validateDataUsingZodSchema(response.data, z.array(chemicalSchema));

    return isDataValid ? response.data : undefined;
  },
);

export const getMultiChemicals = createAsyncThunk(
  'project/getMultChemicals',
  async (searchQueries: string[], { dispatch }): Promise<void> => {
    const asyncGetChemicalsFunctions = searchQueries.map(searchQuery =>
      dispatch(getChemicals(searchQuery)),
    );

    await Promise.all(asyncGetChemicalsFunctions);
  },
);
