import { overlayBioEntityFixture } from '@/models/fixtures/overlayBioEntityFixture';
import { OverlayBioEntity } from '@/types/models';
import { calculateOvarlaysOrder, getValidOverlayBioEntities } from './overlayBioEntity.utils';

describe('calculateOverlaysOrder', () => {
  const cases = [
    {
      data: [
        { idObject: 1, order: 11 },
        { idObject: 2, order: 12 },
        { idObject: 3, order: 13 },
      ],
      expected: [
        { id: 1, order: 11, calculatedOrder: 1, index: 0 },
        { id: 2, order: 12, calculatedOrder: 2, index: 1 },
        { id: 3, order: 13, calculatedOrder: 3, index: 2 },
      ],
    },
    // different order
    {
      data: [
        { idObject: 2, order: 12 },
        { idObject: 3, order: 13 },
        { idObject: 1, order: 11 },
      ],
      expected: [
        { id: 1, order: 11, calculatedOrder: 1, index: 0 },
        { id: 2, order: 12, calculatedOrder: 2, index: 1 },
        { id: 3, order: 13, calculatedOrder: 3, index: 2 },
      ],
    },
    {
      data: [
        { idObject: 1, order: 11 },
        { idObject: 2, order: 11 },
        { idObject: 3, order: 11 },
      ],
      expected: [
        { id: 1, order: 11, calculatedOrder: 1, index: 0 },
        { id: 2, order: 11, calculatedOrder: 2, index: 1 },
        { id: 3, order: 11, calculatedOrder: 3, index: 2 },
      ],
    },
    // different order
    {
      data: [
        { idObject: 2, order: 11 },
        { idObject: 3, order: 11 },
        { idObject: 1, order: 11 },
      ],
      expected: [
        { id: 1, order: 11, calculatedOrder: 1, index: 0 },
        { id: 2, order: 11, calculatedOrder: 2, index: 1 },
        { id: 3, order: 11, calculatedOrder: 3, index: 2 },
      ],
    },
    {
      data: [],
      expected: [],
    },
  ];

  it.each(cases)('should return valid overlays order', ({ data, expected }) => {
    expect(calculateOvarlaysOrder(data)).toStrictEqual(expected);
  });
});

describe('getValidOverlayBioEntities', () => {
  it('should return empty array if overlayBioEntities are empty array', () => {
    const result = getValidOverlayBioEntities([]);

    expect(result).toEqual([]);
  });
  it('should return the same overlayBioEntities if all overlayBioEntities are valid', () => {
    const result = getValidOverlayBioEntities(overlayBioEntityFixture);
    expect(result).toEqual(overlayBioEntityFixture);
  });
  it('should filter properly and return valid overlayBioEntities if overlayBioEntities are mixed array with valid and invalid entities', () => {
    const invalidOverlayBioEntities = overlayBioEntityFixture.map(overlayBioEntity => ({
      ...overlayBioEntity,
      left: {},
    })) as OverlayBioEntity[];

    const result = getValidOverlayBioEntities([
      ...overlayBioEntityFixture,
      ...invalidOverlayBioEntities,
    ]);
    expect(result).toEqual(overlayBioEntityFixture);
  });
  it('should return empty array if all overlayBioEntities are invalid', () => {
    const invalidOverlayBioEntities = overlayBioEntityFixture.map(overlayBioEntity => ({
      ...overlayBioEntity,
      right: {},
    })) as OverlayBioEntity[];

    const result = getValidOverlayBioEntities(invalidOverlayBioEntities);

    expect(result).toEqual([]);
  });
});
